@@ -1,9 +1,9 @@
 package Net::DNS::Domain;
 
 #
-# $Id: Domain.pm 1611 2018-01-02 09:41:24Z willem $
+# $Id: Domain.pm 1698 2018-07-24 15:29:05Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1611 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1698 $)[1];
 
 
 =head1 NAME
@@ -46,7 +46,7 @@ use constant ASCII => ref eval {
 	Encode::find_encoding('ascii');
 };
 
-use constant UTF8 => scalar eval {	## not UTF-EBCDIC  [see UTR#16 3.6]
+use constant UTF8 => scalar eval {	## not UTF-EBCDIC  [see Unicode TR#16 3.6]
 	Encode::encode_utf8( chr(182) ) eq pack( 'H*', 'C2B6' );
 };
 
@@ -397,8 +397,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::LibIDN2>, L<Net::DNS>, RFC1034, RFC1035, RFC5891,
-Unicode Technical Report #16
+L<perl>, L<Net::DNS>, L<Net::LibIDN2>, RFC1034, RFC1035, RFC5891, Unicode TR#16
 
 =cut
 
