@@ -1,9 +1,9 @@
 package Net::DNS::Packet;
 
 #
-# $Id: Packet.pm 1584 2017-07-28 16:15:17Z willem $
+# $Id: Packet.pm 1714 2018-09-21 14:14:55Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1584 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1714 $)[1];
 
 
 =head1 NAME
@@ -130,7 +130,7 @@ sub decode {
 			answer	   => [],
 			authority  => [],
 			additional => [],
-			answersize => length $$data
+			replysize  => length $$data
 			}, $class;
 
 		# question/zone section
@@ -361,8 +361,8 @@ sub additional {
 
     $packet->print;
 
-Prints the packet data on the standard output in an ASCII format
-similar to that used in DNS zone files.
+Prints the entire packet to the currently selected output filehandle
+using the master file format mandated by RFC1035.
 
 =cut
 
@@ -383,9 +383,9 @@ sub string {
 	my $header = $self->header;
 	my $update = $header->opcode eq 'UPDATE';
 
-	my $server = $self->{answerfrom};
-	my $length = $self->{answersize};
-	my $string = $server ? ";; Answer received from $server ($length bytes)\n" : "";
+	my $server = $self->{replyfrom};
+	my $length = $self->{replysize};
+	my $string = $server ? ";; Response received from $server ($length octets)\n" : "";
 
 	$string .= ";; HEADER SECTION\n" . $header->string;
 
@@ -416,37 +416,41 @@ sub string {
 }
 
 
-=head2 answerfrom
+=head2 from
 
-    print "packet received from ", $packet->answerfrom, "\n";
+    print "packet received from ", $packet->from, "\n";
 
 Returns the IP address from which this packet was received.
-User-created packets will return undef for this method.
+This method will return undef for user-created packets.
 
 =cut
 
-sub answerfrom {
+sub from {
 	my $self = shift;
 
-	$self->{answerfrom} = shift if scalar @_;
-	$self->{answerfrom};
+	$self->{replyfrom} = shift if scalar @_;
+	$self->{replyfrom};
 }
 
+sub answerfrom { &from; }					# uncoverable pod
 
-=head2 answersize
 
-    print "packet size: ", $packet->answersize, " bytes\n";
+=head2 size
 
-Returns the size of the packet in bytes as it was received from a
-nameserver.  User-created packets will return undef for this method
+    print "packet size: ", $packet->size, " octets\n";
+
+Returns the size of the packet in octets as it was received from a
+nameserver.  This method will return undef for user-created packets
 (use length($packet->data) instead).
 
 =cut
 
-sub answersize {
-	shift->{answersize};
+sub size {
+	shift->{replysize};
 }
 
+sub answersize { &size; }					# uncoverable pod
+
 
 =head2 push
 
