@@ -1,13 +1,13 @@
 package Net::DNS::RR::CSYNC;
 
 #
-# $Id: CSYNC.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: CSYNC.pm 1597 2017-09-22 08:04:02Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
@@ -37,7 +37,6 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless defined $self->{typebm};
 	pack 'N n a*', $self->soaserial, $self->flags, $self->{typebm};
 }
 
@@ -45,7 +44,6 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless defined $self->{typebm};
 	my @rdata = ( $self->soaserial, $self->flags, $self->typelist );
 }
 
@@ -82,8 +80,7 @@ sub immediate {
 	my $bit = 0x0001;
 	for ( shift->{flags} ) {
 		my $set = $bit | ( $_ ||= 0 );
-		return $bit & $_ unless scalar @_;
-		$_ = (shift) ? $set : ( $set ^ $bit );
+		$_ = (shift) ? $set : ( $set ^ $bit ) if scalar @_;
 		return $_ & $bit;
 	}
 }
@@ -93,8 +90,7 @@ sub soaminimum {
 	my $bit = 0x0002;
 	for ( shift->{flags} ) {
 		my $set = $bit | ( $_ ||= 0 );
-		return $bit & $_ unless scalar @_;
-		$_ = (shift) ? $set : ( $set ^ $bit );
+		$_ = (shift) ? $set : ( $set ^ $bit ) if scalar @_;
 		return $_ & $bit;
 	}
 }
