@@ -1,9 +1,9 @@
 package Net::DNS::RR::RRSIG;
 
 #
-# $Id: RRSIG.pm 1690 2018-07-03 09:02:10Z willem $
+# $Id: RRSIG.pm 1709 2018-09-07 08:03:09Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1690 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1709 $)[1];
 
 
 use strict;
@@ -29,23 +29,24 @@ use constant DEBUG => 0;
 
 use constant UTIL => defined eval 'use Scalar::Util 1.25; 1;';
 
-use constant PRIVATE => defined eval 'require Net::DNS::SEC::Private';
+# IMPORTANT: Distros MUST NOT create dependencies on Net::DNS::SEC	(Prohibited in many territories)
+use constant PRIVATE => 'Net::DNS::SEC::Private';
+use constant DSA     => 'Net::DNS::SEC::DSA';
+use constant RSA     => 'Net::DNS::SEC::RSA';
+use constant ECDSA   => 'Net::DNS::SEC::ECDSA';
+use constant EdDSA   => 'Net::DNS::SEC::EdDSA';
+use constant ECCGOST => 'Net::DNS::SEC::ECCGOST';
 
-use constant DSA => defined eval 'require Net::DNS::SEC::DSA';
-use constant RSA => defined eval 'require Net::DNS::SEC::RSA';
+use constant EXISTS => join '', qw(r e q u i r e);		# Defeat static analysers and grep
+use constant DNSSEC => defined( eval join ' ', EXISTS, PRIVATE );
 
-use constant ECDSA => defined eval 'require Net::DNS::SEC::ECDSA';
-use constant EdDSA => defined eval 'require Net::DNS::SEC::EdDSA';
-use constant GOST  => defined eval 'require Digest::GOST; require Net::DNS::SEC::ECCGOST';
+my ($DSA) = grep { DNSSEC && defined( eval join ' ', EXISTS, $_ ) } DSA;
+my ($RSA) = grep { DNSSEC && defined( eval join ' ', EXISTS, $_ ) } RSA;
 
-use constant DNSSEC => PRIVATE && ( RSA || DSA || ECDSA || EdDSA );
-
-my $DSA = DSA ? 'Net::DNS::SEC::DSA' : 0;
-my $RSA = RSA ? 'Net::DNS::SEC::RSA' : 0;
-
-my $ECDSA = ECDSA ? 'Net::DNS::SEC::ECDSA'   : 0;
-my $EdDSA = EdDSA ? 'Net::DNS::SEC::EdDSA'   : 0;
-my $GOST  = GOST  ? 'Net::DNS::SEC::ECCGOST' : 0;
+my ($ECDSA) = grep { DNSSEC && defined( eval join ' ', EXISTS, $_ ) } ECDSA;
+my ($EdDSA) = grep { DNSSEC && defined( eval join ' ', EXISTS, $_ ) } EdDSA;
+use constant GOST => defined( eval join ' ', EXISTS, 'Digest::GOST' );
+my ($ECCGOST) = grep { DNSSEC && GOST && defined( eval join ' ', EXISTS, $_ ) } ECCGOST;
 
 my @field = qw(typecovered algorithm labels orgttl sigexpiration siginception keytag);
 
@@ -143,23 +144,27 @@ sub _defaults {				## specify RR attribute default values
 }
 
 
-my %DNSSEC_sign = (
+my %DNSSEC_verify = (
+	1  => $RSA,
+	3  => $DSA,
 	5  => $RSA,
+	6  => $DSA,
 	7  => $RSA,
 	8  => $RSA,
 	10 => $RSA,
+	12 => $ECCGOST,
 	13 => $ECDSA,
 	14 => $ECDSA,
 	15 => $EdDSA,
 	16 => $EdDSA,
 	);
 
-my %DNSSEC_verify = (
-	1  => $RSA,
-	3  => $DSA,
-	6  => $DSA,
-	12 => $GOST,
-	%DNSSEC_sign,
+my %DNSSEC_sign = (
+	%DNSSEC_verify,
+	1  => 0,			## deprecated ##
+	3  => 0,			## deprecated ##
+	6  => 0,			## deprecated ##
+	12 => 0,			## deprecated ##
 	);
 
 
@@ -603,8 +608,8 @@ __END__
 
     use Net::DNS::SEC;
     $sigrr = create Net::DNS::RR::RRSIG( \@rrset, $keypath,
-					sigex => 20171231010101
-					sigin => 20171201010101
+					sigex => 20181231010101
+					sigin => 20181201010101
 					);
 
     $sigrr->verify( \@rrset, $keyrr ) || die $sigrr->vrfyerrstr;
@@ -728,8 +733,8 @@ Create a signature over a RR set.
     $sigrr = create Net::DNS::RR::RRSIG( \@rrsetref, $keypath );
 
     $sigrr = create Net::DNS::RR::RRSIG( \@rrsetref, $keypath,
-					sigex => 20171231010101
-					sigin => 20171201010101
+					sigex => 20181231010101
+					sigin => 20181201010101
 					);
     $sigrr->print;
 
@@ -755,8 +760,8 @@ containing the private key as generated by dnssec-keygen.
 The optional remaining arguments consist of ( name => value ) pairs
 as follows:
 
-	sigex  => 20171231010101,	# signature expiration
-	sigin  => 20171201010101,	# signature inception
+	sigex  => 20181231010101,	# signature expiration
+	sigin  => 20181201010101,	# signature inception
 	sigval => 30,			# validity window (days)
 	ttl    => 3600			# TTL
 
