@@ -15,9 +15,9 @@ sub UNITCHECK {				## restore %SIG after compilation
 package Net::DNS::RR::SIG;
 
 #
-# $Id: SIG.pm 1611 2018-01-02 09:41:24Z willem $
+# $Id: SIG.pm 1709 2018-09-07 08:03:09Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1611 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1709 $)[1];
 
 
 use strict;
@@ -44,12 +44,19 @@ use constant DEBUG => 0;
 
 use constant UTIL => defined eval 'use Scalar::Util 1.25; 1;';
 
-use constant PRIVATE => defined eval 'require Net::DNS::SEC::Private';
+# IMPORTANT: Distros MUST NOT create dependencies on Net::DNS::SEC	(Prohibited in many territories)
+use constant PRIVATE => 'Net::DNS::SEC::Private';
+use constant DSA     => 'Net::DNS::SEC::DSA';
+use constant RSA     => 'Net::DNS::SEC::RSA';
+use constant ECDSA   => 'Net::DNS::SEC::ECDSA';
+use constant EdDSA   => 'Net::DNS::SEC::EdDSA';
+use constant ECCGOST => 'Net::DNS::SEC::ECCGOST';
 
-use constant DSA => defined eval 'require Net::DNS::SEC::DSA';
-use constant RSA => defined eval 'require Net::DNS::SEC::RSA';
+use constant EXISTS => join '', qw(r e q u i r e);		# Defeat static analysers and grep
+use constant DNSSEC => defined( eval join ' ', EXISTS, PRIVATE );
 
-use constant DNSSEC => PRIVATE && ( RSA || DSA );
+my ($DSA) = grep { DNSSEC && defined( eval join ' ', EXISTS, $_ ) } DSA;
+my ($RSA) = grep { DNSSEC && defined( eval join ' ', EXISTS, $_ ) } RSA;
 
 my @field = qw(typecovered algorithm labels orgttl sigexpiration siginception keytag);
 
@@ -166,23 +173,26 @@ sub _defaults {				## specify RR attribute default values
 }
 
 
-my $DSA = DSA ? 'Net::DNS::SEC::DSA' : 0;
-my $RSA = RSA ? 'Net::DNS::SEC::RSA' : 0;
-
-my %SEC = (
-	1 => $RSA,
-	3 => $DSA,
-	5 => $RSA,
-	6 => $DSA,
-	7 => $RSA,
+my %DNSSEC_sign = (
+	1  => $RSA,
+	3  => $DSA,
+	5  => $RSA,
+	6  => $DSA,
+	7  => $RSA,
+	8  => $RSA,
+	10 => $RSA,
 	);
 
+my %DNSSEC_verify = %DNSSEC_sign;
+
 my %siglen = (
-	1 => 128,
-	3 => 41,
-	5 => 256,
-	6 => 41,
-	7 => 256,
+	1  => 128,
+	3  => 41,
+	5  => 256,
+	6  => 41,
+	7  => 256,
+	8  => 256,
+	10 => 256,
 	);
 
 
@@ -523,7 +533,7 @@ sub _CreateSig {
 		my $self = shift;
 
 		my $algorithm = $self->algorithm;
-		my $class     = $SEC{$algorithm};
+		my $class     = $DNSSEC_sign{$algorithm};
 
 		eval {
 			die "algorithm $algorithm not supported" unless $class;
@@ -538,7 +548,7 @@ sub _VerifySig {
 		my $self = shift;
 
 		my $algorithm = $self->algorithm;
-		my $class     = $SEC{$algorithm};
+		my $class     = $DNSSEC_verify{$algorithm};
 
 		my $retval = eval {
 			die "algorithm $algorithm not supported" unless $class;
@@ -692,14 +702,14 @@ the private key stored in the key file.
 The first argument is a scalar that contains the data to be signed.
 
 The second argument is a string which specifies the path to a file
-containing the private key as generated with dnssec-keygen, a program
+containing the private key as generated using dnssec-keygen, a program
 that comes with the ISC BIND distribution.
 
 The optional remaining arguments consist of ( name => value ) pairs
 as follows:
 
-	sigin  => 20171201010101,	# signature inception
-	sigex  => 20171201011101,	# signature expiration
+	sigin  => 20181201010101,	# signature inception
+	sigex  => 20181201011101,	# signature expiration
 	sigval => 10,			# validity window (minutes)
 
 The sigin and sigex values may be specified as Perl time values or as
@@ -715,9 +725,9 @@ By default the signature is valid for 10 minutes.
 
 =item *
 
-Do not change the name of the file generated by dnssec-keygen, the
-create method uses the filename as generated by dnssec-keygen to
-determine the keyowner, algorithm and the keyid (keytag).
+Do not change the name of the private key file.
+The create method uses the filename as generated by dnssec-keygen
+to determine the keyowner, algorithm, and the keyid (keytag).
 
 =back
 
@@ -752,15 +762,18 @@ Returns false on error and sets $sig->vrfyerrstr
 The code is not optimised for speed.
 
 If this code is still around in 2100 (not a leap year) you will
-need to check for proper handling of times ...
+need to check for proper handling of times after 28th February.
 
 =head1 ACKNOWLEDGMENTS
 
-Andy Vaskys (Network Associates Laboratories) supplied the code for
-handling RSA with SHA1 (Algorithm 5).
+Although their original code may have disappeared following redesign of
+Net::DNS, Net::DNS::SEC and the OpenSSL API, the following individual
+contributors deserve to be recognised for their significant influence
+on the development of the SIG package.
 
-T.J. Mather, the Crypt::OpenSSL::DSA maintainer, for his quick
-responses to bug report and feature requests.
+Andy Vaskys (Network Associates Laboratories) supplied code for RSA.
+
+T.J. Mather provided support for the DSA algorithm.
 
 
 =head1 COPYRIGHT
